<!--
SPDX-FileCopyrightText: 2020 Evandro Chagas Ribeiro da Rosa <evandro@quantuloop.com>
SPDX-FileCopyrightText: 2020 Rafael de Santiago <r.santiago@ufsc.br>

SPDX-License-Identifier: Apache-2.0
-->

# Libket

Libket serves as the core of the Ket Quantum Programming platform, providing a runtime library for the quantum programming language Ket, as well as simple interfaces for developing quantum applications in C and Rust. For more information,
please refer to the documentation at <https://quantumket.org>.

## License

Libket is released under the Apache-2.0 License. See [LICENSE](LICENSE) for more information.
